# CMake file
# Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2010-2015
# Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2010-2015
# Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
#
# See the file LICENSE.txt in the package base directory for details
#
# @file InstallationConfiguration.cmake.in
#       Used to set all the variables that where detected in the find modules to provide
#       a way to load the configuration of an installed GTI.
#
# @author Tobias Hilbrich
# @date 19.11.2010

## TODO: -Keep up to date     

###Fortran
SET (GTI_ENABLE_FORTRAN "ON" CACHE PATH  "" FORCE)

### GTI version
SET (GTI_VERSION "1.5.0")

###MPI
SET (MPI_C_COMPILER "/usr/lib64/mpich/bin/mpicc" CACHE PATH "" FORCE)
SET (MPI_C_COMPILE_FLAGS " -fexceptions  -fstack-protector-strong  -fPIC" CACHE PATH "" FORCE)
SET (MPI_C_INCLUDE_PATH "/usr/include/mpich-x86_64" CACHE PATH "" FORCE)
SET (MPI_C_LINK_FLAGS " -Wl,-z,noexecstack  -Wl,-rpath  -Wl,/usr/lib64/mpich/lib" CACHE PATH "" FORCE)
SET (MPI_C_LIBRARIES /usr/lib64/mpich/lib/libmpich.so;/usr/lib64/mpich/lib/libopa.so;/usr/lib64/mpich/lib/libmpl.so;/usr/lib64/librt.so;/usr/lib64/libpthread.so CACHE PATH "" FORCE)

SET (MPI_CXX_COMPILER "/usr/lib64/mpich/bin/mpicxx" CACHE PATH "" FORCE)
SET (MPI_CXX_COMPILE_FLAGS " -fexceptions  -fstack-protector-strong  -fPIC" CACHE PATH "" FORCE)
SET (MPI_CXX_INCLUDE_PATH "/usr/include/mpich-x86_64" CACHE PATH "" FORCE)
SET (MPI_CXX_LINK_FLAGS " -Wl,-z,noexecstack  -Wl,-rpath  -Wl,/usr/lib64/mpich/lib" CACHE PATH "" FORCE)
SET (MPI_CXX_LIBRARIES /usr/lib64/mpich/lib/libmpichcxx.so;/usr/lib64/mpich/lib/libmpich.so;/usr/lib64/mpich/lib/libopa.so;/usr/lib64/mpich/lib/libmpl.so;/usr/lib64/librt.so;/usr/lib64/libpthread.so CACHE PATH "" FORCE)

SET (MPI_Fortran_COMPILER "/usr/lib64/mpich/bin/mpif90" CACHE PATH "" FORCE)
SET (MPI_Fortran_COMPILE_FLAGS " -fexceptions  -fstack-protector-strong  -fPIC" CACHE PATH "" FORCE)
SET (MPI_Fortran_INCLUDE_PATH "/usr/include/mpich-x86_64;/usr/include/mpich-x86_64" CACHE PATH "" FORCE)
SET (MPI_Fortran_LINK_FLAGS " -Wl,-z,noexecstack  -Wl,-rpath  -Wl,/usr/lib64/mpich/lib" CACHE PATH "" FORCE)
SET (MPI_Fortran_LIBRARIES /usr/lib64/mpich/lib/libmpichf90.so;/usr/lib64/mpich/lib/libmpich.so;/usr/lib64/mpich/lib/libopa.so;/usr/lib64/mpich/lib/libmpl.so;/usr/lib64/librt.so;/usr/lib64/libpthread.so CACHE PATH "" FORCE)

SET (MPIEXEC "/usr/lib64/mpich/bin/mpiexec" CACHE PATH "" FORCE)
SET (MPIEXEC_NUMPROC_FLAG "-np" CACHE PATH "" FORCE)
SET (MPIEXEC_PREFLAGS "" CACHE PATH "" FORCE)
SET (MPIEXEC_POSTFLAGS "" CACHE PATH "" FORCE)

SET (MPI_CXX_SKIP_FLAGS -DMPI_NO_CPPBIND;-DOMPI_SKIP_MPICXX;-D_MPICC_H;-DMPICH_SKIP_MPICXX;-DMPIBULL_SKIP_MPICXX CACHE STRING "" FORCE)

SET (HAVE_MPI_NO_CONST_CORRECTNESS False CACHE INTERNAL "" FORCE)
SET (HAVE_MPI_ADDRESS_CONST_CORRECT TRUE CACHE INTERNAL "" FORCE)
SET (HAVE_MPI_TYPE_HINDEXED_CONST_CORRECT TRUE CACHE INTERNAL "" FORCE)
SET (HAVE_MPI_TYPE_STRUCT_CONST_CORRECT TRUE CACHE INTERNAL "" FORCE)

###PnMPI
#TODO currently computed by GTI
SET (PnMPI_HOME "/usr/lib64/mpich" CACHE PATH "" FORCE)
SET (PnMPI_LIBRARY_DIR "/usr/lib64/mpich/lib" CACHE PATH "" FORCE)
SET (PNMPI_PATCHER "/usr/lib64/mpich/bin/pnmpi-patch" CACHE FILEPATH "" FORCE)
SET (PNMPI_LIB_NAME "libpnmpi.so.1.5.0" CACHE FILEPATH "" FORCE)
SET (PNMPI_Fortran_LIB_NAME "libpnmpif.so" CACHE FILEPATH "" FORCE)

SET (PnMPI_C_LIBRARIES "/usr/lib64/mpich/lib/libpnmpi.so.1.5.0" CACHE STRING "" FORCE)
SET (PnMPI_Fortran_LIBRARIES "/usr/lib64/mpich/lib/libpnmpif.so" CACHE STRING "" FORCE)
SET (PnMPI_INCLUDE_DIR "/usr/include/mpich-x86_64" CACHE PATH "" FORCE)

##OMPT
SET (GTI_FOUND_OMPT "FALSE" CACHE BOOL "Does GTI/MUST link against a OMPT supporting OpenMP Runtime" FORCE)
SET (GTI_OMPT_INCLUDE_PATH "GTI_OMPT_INCLUDE_PATH-NOTFOUND" CACHE PATH "Path to the include files of the OMPT supporting OpenMP Runtime" FORCE)
SET (GTI_OMPT_LIB_PATH "GTI_OMPT_LIBS-NOTFOUND" CACHE PATH "Path to the library files of the OMPT supporting OpenMP Runtime" FORCE)
IF (GTI_FOUND_OMPT AND GTI_OMPT_INCLUDE_PATH AND GTI_OMPT_LIB_PATH)
    add_definitions(-DGTI_FOUND_OMPT)
ENDIF (GTI_FOUND_OMPT AND GTI_OMPT_INCLUDE_PATH AND GTI_OMPT_LIB_PATH)

##LIBUNWIND
SET (GTI_FOUND_LIBUNWIND "FALSE" CACHE BOOL "Does GTI/MUST link against libunwind" FORCE)
SET (GTI_LIBUNWIND_INCLUDE_PATH "GTI_LIBUNWIND_INCLUDE_PATH-NOTFOUND" CACHE PATH "Path to the include files of libunwind" FORCE)
SET (GTI_LIBUNWIND_LIB_PATH "GTI_LIBUNWIND_LIB_PATH-NOTFOUND" CACHE PATH "Path to the library files of libunwind" FORCE)
IF (GTI_FOUND_LIBUNWIND AND GTI_LIBUNWIND_INCLUDE_PATH AND GTI_LIBUNWIND_LIB_PATH)
    add_definitions(-DGTI_FOUND_LIBUNWIND)
ENDIF (GTI_FOUND_LIBUNWIND AND GTI_LIBUNWIND_INCLUDE_PATH AND GTI_LIBUNWIND_LIB_PATH)

