/*
 * GTI (Generic Tools Infrastructure)
 * Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2015
 * Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2015
 * Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
 *
 * See the file LICENSE.txt in the package base directory for details
 */

/**
 * @file I_BreakEnforcer.h
 *       @see I_BreakEnforcer.
 *
 *  @date 02.09.2013
 *  @author Tobias Hilbrich
 */

#include "I_Module.h"
#include "GtiEnums.h"

#ifndef I_BREAKENFORCER_H
#define I_BREAKENFORCER_H

/**
 * Runs on application processes and checks whether we got a break.
 * If so we busy wait for the resume command.
 *
 * Dependencies (order as listed):
 * - X
 *
 */
class I_BreakEnforcer : public gti::I_Module
{
public:

    /**
     * Tests whether we got the break command.
     * @return see gti::GTI_ANALYSIS_RETURN.
     */
    virtual gti::GTI_ANALYSIS_RETURN test (
            void) = 0;

    /**
     * Handles gtiBroadcastBreak events.
     * @return see gti::GTI_ANALYSIS_RETURN.
     */
    virtual gti::GTI_ANALYSIS_RETURN handleBroadcastBreak (
            int code) = 0;

};/*class I_BreakEnforcer*/

#endif /*I_BREAKENFORCER_H*/
