/*
 * GTI (Generic Tools Infrastructure)
 * Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2015
 * Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2015
 * Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
 *
 * See the file LICENSE.txt in the package base directory for details
 */

/**
 * @file I_PanicReceiver.h
 *       @see I_PanicReceiver.
 *
 *  @date 11.07.2012
 *  @author Tobias Hilbrich, Joachim Protze, Mathias Korepkat
 */

#include "I_Module.h"
#include "GtiEnums.h"

#ifndef I_PANICRECEIVER_H
#define I_PANICRECEIVER_H

/**
 * Listens for any incoming panic notifications or flush requests.
 *
 * Dependencies (order as listed):
 * - X
 *
 */
class I_PanicReceiver : public gti::I_Module
{
public:

    /**
     * Called when a panic notification arrives.
     *
     * @return see gti::GTI_ANALYSIS_RETURN.
     */
    virtual gti::GTI_ANALYSIS_RETURN notifyPanic (void) = 0;

    /**
     * Called when a panic notification arrives.
     *
     * @return see gti::GTI_ANALYSIS_RETURN.
     */
    virtual gti::GTI_ANALYSIS_RETURN notifyFlush (void) = 0;

    /**
     * Called when a gtiRaisePanic event crosses this TBON node.
     *
     * @return see gti::GTI_ANALYSIS_RETURN.
     */
    virtual gti::GTI_ANALYSIS_RETURN notifyRaisePanic (void) = 0;

};/*class I_PanicReceiver*/

#endif /*I_PANICRECEIVER_H*/
