/*
 * GTI (Generic Tools Infrastructure)
 * Copyright (C) ZIH, Technische Universitaet Dresden, Federal Republic of Germany, 2011-2015
 * Copyright (C) Lawrence Livermore National Laboratories, United States of America, 2011-2015
 * Copyright (C) RWTH Aachen University, Federal Republic of Germany, 2013-2015
 *
 * See the file LICENSE.txt in the package base directory for details
 */

/**
 * @file I_ShutdownHandler.h
 *       @see I_ShutdownHandler.
 *
 *  @date 27.06.2012
 *  @author Tobias Hilbrich, Joachim Protze, Mathias Korepkat
 */

#include "I_Module.h"
#include "GtiEnums.h"
#include "I_ChannelId.h"

#ifndef I_SHUTDOWNHANDLER_H
#define I_SHUTDOWNHANDLER_H

/**
 * Handler for GTI shutdown.
 * Waits till the last shutdown event arrives and then broadcasts a notification event that lets all
 * preceding layers shut down.
 *
 * Dependencies (order as listed):
 * - X
 */
class I_ShutdownHandler : public gti::I_Module
{
public:

    /**
     * Notification of a shutdown event.
     *
     * @param channelId of the event.
     * @return see gti::GTI_ANALYSIS_RETURN.
     */
    virtual gti::GTI_ANALYSIS_RETURN notifyShutdown (gti::I_ChannelId* channelId) = 0;

};/*class I_ShutdownHandler*/

#endif /*I_SHUTDOWNHANDLER_H*/
